@@ -16,7 +16,7 @@
 #include "webserver.h"
 #include "WebPages.h"
 
-#define VERSION 1.2
+#define VERSION 1.3
 
 extern char *getfqdn(char *);
 extern void trim(char *);
@@ -129,7 +129,7 @@ Status_Page(char *source, char *dest, int size)
 {
 	if (source && dest && size) {
 		snprintf(dest, size,
-			 "<HTML><BODY><H1><CENTER>Welcome to SNARE for Irix version 1.2</H1><P>Please select from the menu on the left.</CENTER><p>\nStatus: <font color=green>Snare for Irix is currently running.</font>\n</BODY></HTML>");
+			 "<HTML><BODY><H1><CENTER>Welcome to SNARE for Irix version 1.3</H1><P>Please select from the menu on the left.</CENTER><p>\nStatus: <font color=green>Snare for Irix is currently running.</font>\n</BODY></HTML>");
 	}
 	return (0);
 }
@@ -2534,7 +2534,7 @@ DefaultHeader(char *source, char *dest, int size)
 		"   <br><br><font size=-2><A HREF=\"/Users\" style=\"color:FFFFFF;text-decoration:none\">Display a list of Users</A><br>\n"
 		"   <br><A HREF=\"/Groups\" style=\"color:FFFFFF;text-decoration:none\">Display a list of Groups</A><br>\n"
 		"   <br><A HREF=\"/GroupMembers\" style=\"color:FFFFFF;text-decoration:none\">Display a list of GroupMembers</A><br>\n"
-		"   <br><br><A HREF=\"http://www.intersectalliance.com/snareserver/index.html\" style=\"color:FFFFFF;text-decoration:none\"><b>Snare Server Information</b></A><br>\n"
+		"   <br><br><A HREF=\"http://www.intersectalliance.com/snareserver/index.html\" style=\"color:FFFFFF;text-decoration:none\">Snare Server Information</A><br>\n"
 		"   </b></font>\n"
 		"   <br>\n"
 		"   </div>\n"
