@@ -1,12 +1,12 @@
 /**********************************************************
  *
- * Snare for Irix version 1.2
+ * Snare for Irix version 1.3
  *
  * Author: InterSect Alliance Pty Ltd
  *
  * Copyright 2001-2004 InterSect Alliance Pty Ltd
  *
- * Last Modified: 14/7/2004
+ * Last Modified: 5/3/2005
  *
  * Available under the terms of the GNU Public Licence.
  * - See www.gnu.org
@@ -1324,6 +1324,7 @@ sendevent(char *string, int criticality)
 	if (AuditDestination & AUDIT_TO_STDOUT) {
 		// Send to STDOUT.
 		printf("%s\n", stringout);
+		fflush(stdout);
 	}
 
 	if (AuditDestination & AUDIT_TO_FILE) {
@@ -1410,6 +1411,9 @@ GetIrixDetails(char *logbuffer, char *username, char *searchterm,
 	char *position = logbuffer;
 	char tempreturn[20] = "";
 
+	char * tlogbuffer=logbuffer;
+	char * tposition=(char *)NULL;
+
 	if (!logbuffer || !username || !searchterm || !eventname || !options) {
 		return (0);
 	}
@@ -1465,7 +1469,19 @@ GetIrixDetails(char *logbuffer, char *username, char *searchterm,
 		}
 	}
 
-	position = FindToken("PATHNAME=", logbuffer);
+
+	// Find the LAST PATHNAME= in the list.
+	position=(char *)NULL;
+	tposition=tlogbuffer;
+	do {
+		tposition=FindToken("PATHNAME=", tposition);
+		if(tposition) {
+			position=tposition;					// Save position of this "PATHNAME=" token
+			// Jump over this PATHNAME token
+			tposition+=strlen("PATHNAME=");
+		}
+	} while(tposition);
+
 	if (position) {
 		char EVENTpath[MAX_PATH] = "";
 		char CWDpath[MAX_PATH] = "";
@@ -1482,6 +1498,10 @@ GetIrixDetails(char *logbuffer, char *username, char *searchterm,
 		resolved_path(CWDpath, EVENTpath, searchterm);
 
 	} else {
+		// PATHNAME token was NOT found: 
+		//	If this is sat_exec or sat_exit, try to use the COMMAND as the searchterm
+		//	Otherwise, try using CWD as the searchterm. 
+		//	If for some reason there is no CWD, then use the entire buffer as the searchterm
 		if (!strncmp(eventname, "sat_exit", 8)
 		    || !strncmp(eventname, "sat_exec", 8)) {
 			position = FindToken("COMMAND=", logbuffer);
@@ -1491,10 +1511,19 @@ GetIrixDetails(char *logbuffer, char *username, char *searchterm,
 				strncpy(searchterm, "Unknown", MAX_PATH);
 			}
 		} else {
-			// MAYBE ADD *UID* searching here..
+			char CWDpath[MAX_PATH] = "";
 
-			// Not much else we can do - allow the entire buffer to be a search term.
-			strncpy(searchterm, logbuffer, MAX_PATH);
+			position = FindToken("CWD=", logbuffer);
+			if (position) {
+				GetElement(position, 0, CWDpath,
+					   sizeof (CWDpath));
+				resolved_path(CWDpath, "", searchterm);
+			} else {
+				// MAYBE ADD *UID* searching here..
+
+				// Not much else we can do - allow the entire buffer to be a search term.
+				strncpy(searchterm, logbuffer, MAX_PATH);
+			}
 		}
 	}
 
